*********
Changelog
*********

See the `Releases page`_ on Github for a complete list of commits that are
included in each version.

1.1.0 (2023-05-30)
------------------

- Add support for configuring Apt repositories in non-default roots

1.0.0 (2023-05-24)
------------------

This release marks the stability of craft-archives' API. Most of the work
has been on internal refactorings and tooling.

- Add support for Ubuntu Cloud Archive repositories
- Unify package repositories representations

.. _Releases page: https://github.com/canonical/craft-archives/releases
